@@ -23,18 +23,21 @@
 #' @references
 #' \insertAllCited{}
 #' @export
-Consensus <- function (trees, p = 1, check.labels = TRUE) {
+Consensus <- function(trees, p = 1, check.labels = TRUE) {
   if (length(trees) == 1L) {
     return(trees[[1]])
   }
   if (inherits(trees, 'phylo')) {
     return(trees)
   }
+  if (!is.list(trees) || is.data.frame(trees)) {
+    stop("Expecting `trees` to be a list.")
+  }
   repeat {
     nTip <- NTip(trees)
     if (length(unique(nTip)) > 1) {
       warning("Tree sizes differ; removing leaves not in smallest.")
-      trees <- lapply(trees, KeepTip, trees[[which.min(nTip)]]$tip.label)
+      trees <- lapply(trees, KeepTip, trees[[which.min(nTip)]][["tip.label"]])
     } else {
       nTip <- nTip[1]
       break
@@ -52,7 +55,7 @@ Consensus <- function (trees, p = 1, check.labels = TRUE) {
   splits <- as.Splits(consensus_tree(trees, p),
                       tipLabels = TipLabels(trees[[1]]))
   tree1 <- Preorder(trees[[1]])
-  edg <- tree1$edge
+  edg <- tree1[["edge"]]
   root <- edg[DescendantEdges(1, edg[, 1], edg[, 2]), 2]
   root <- root[root <= NTip(tree1)]
 
@@ -96,19 +99,19 @@ Consensus <- function (trees, p = 1, check.labels = TRUE) {
 #'
 #' @template MRS
 #' @export
-ConsensusWithout <- function (trees, tip = character(0), ...) {
+ConsensusWithout <- function(trees, tip = character(0), ...) {
   UseMethod('ConsensusWithout')
 }
 
 #' @rdname ConsensusWithout
 #' @export
-ConsensusWithout.phylo <- function (trees, tip = character(0), ...) {
+ConsensusWithout.phylo <- function(trees, tip = character(0), ...) {
   DropTip(trees, tip = tip)
 }
 
 #' @rdname ConsensusWithout
 #' @export
-ConsensusWithout.multiPhylo <- function (trees, tip = character(0), ...) {
+ConsensusWithout.multiPhylo <- function(trees, tip = character(0), ...) {
   Consensus(lapply(trees, DropTip, tip = tip), ...)
 }
 
@@ -125,7 +128,7 @@ ConsensusWithout.list <- ConsensusWithout.multiPhylo
 #' `tip`s as a legend.
 #' @importFrom graphics legend
 #' @export
-MarkMissing <- function (tip, position = 'bottomleft', ...) {                   # nocov start
+MarkMissing <- function(tip, position = 'bottomleft', ...) {                   # nocov start
   if (length(tip) > 0) {
     legend(position, legend = gsub('_', ' ', tip, fixed = TRUE),
            lwd = 1, lty = 2, bty = 'n', ...)
