@@ -10,25 +10,25 @@
 #' data('Lobo')
 #' as.multiPhylo(Lobo.phy)
 #' @export
-as.multiPhylo <- function (x) UseMethod('as.multiPhylo')
+as.multiPhylo <- function(x) UseMethod('as.multiPhylo')
 
 #' @rdname as.multiPhylo
 #' @export
-as.multiPhylo.phylo <- function (x) c(x)
+as.multiPhylo.phylo <- function(x) c(x)
 
 
 #' @rdname as.multiPhylo
 #' @export
-as.multiPhylo.list <- function (x) structure(x, class = 'multiPhylo')
+as.multiPhylo.list <- function(x) structure(x, class = 'multiPhylo')
 
 #' @rdname as.multiPhylo
 #' @return `as.multiPhylo.phyDat()` returns a list of trees, each corresponding
 #' to the partitions implied by each non-ambiguous character in `x`.
 #' @importFrom ape read.tree
 #' @export
-as.multiPhylo.phyDat <- function (x) {
+as.multiPhylo.phyDat <- function(x) {
   at <- attributes(x)
-  cont <- at$contrast
+  cont <- at[["contrast"]]
   if ('-' %fin% colnames(cont)) {
     cont[cont[, '-'] > 0, ] <- 1
   }
@@ -37,12 +37,12 @@ as.multiPhylo.phyDat <- function (x) {
 
   mat <- matrix(unlist(x), length(x), byrow = TRUE)
   mat[ambiguous[mat]] <- NA
-  mat <- apply(mat, 2, function (x) {
+  mat <- apply(mat, 2, function(x) {
     uniques <- table(x) == 1
     x[x %fin% names(uniques[uniques])] <- NA
     x
   })
-  structure(apply(mat, 2, function (split) {
+  structure(apply(mat, 2, function(split) {
     a <- !is.na(split)
     aSplit <- split[a]
     tokens <- unique(aSplit)
@@ -51,20 +51,20 @@ as.multiPhylo.phyDat <- function (x) {
       read.tree(text = paste0('(', paste(aLabels, collapse = ', '), ');'))
     } else {
       read.tree(text = paste0('((',
-                              paste(vapply(unique(aSplit), function (token) {
+                              paste(vapply(unique(aSplit), function(token) {
                                 paste(aLabels[aSplit == token], collapse = ', ')
                               }, character(1)), collapse = '), ('),
                               '));'))
     }
-  })[at$index], class = 'multiPhylo')
+  })[at[["index"]]], class = 'multiPhylo')
 }
 
 #' @rdname as.multiPhylo
 #' @importFrom ape read.tree
 #' @export
-as.multiPhylo.Splits <- function (x) {
+as.multiPhylo.Splits <- function(x) {
   labels <- TipLabels(x)
-  structure(apply(as.logical(x), 1, function (a) {
+  structure(apply(as.logical(x), 1, function(a) {
     read.tree(text = paste0(
       '((',
       paste0(labels[a], collapse = ','),
