@@ -11,8 +11,9 @@ test_that("Node supports calculated correctly", {
 
   # Internal nodes on each side of root
   balanced <- ape::read.tree(text="((D, (E, (F, out))), (C, (A, B)));")
-  expect_equal(c('10' = 4, '11' = 4, '12' = 4, '13' = 3),
-               SplitFrequency(balanced, treeSample))
+  freq <- SplitFrequency(balanced, treeSample)
+  expect_equal(freq,
+               c("9" = 4, "10" = 4, "11" = 4, "12" = 4, "13" = 3)[names(freq)])
 
 })
 
@@ -35,18 +36,23 @@ test_that("LabelSplits()", {
   expect_error(LabelSplits(BalancedTree(8), 1:8))
   skip_if_not_installed('vdiffr', minimum_version = "1.0.0")
   skip_if(packageVersion("graphics") < "4.1.0")
-  vdiffr::expect_doppelganger('LabelSplits()',  function () {
+  vdiffr::expect_doppelganger('LabelSplits()',  function() {
     tree <- BalancedTree(9)
     plot(tree)
     labs <- letters[6:1]
     names(labs) <- rev(names(as.Splits(tree)))
     LabelSplits(tree, labs, frame = 'circ', cex = 2, bg = 'orange')
   })
+  vdiffr::expect_doppelganger('LabelSplits()-nameless', function() {
+    tree <- BalancedTree(9)
+    plot(tree)
+    LabelSplits(tree, bg = 'orange')
+    expect_warning(LabelSplits(BalancedTree(9), setNames(letters[11:16], 1:6)))
+  })
   vdiffr::expect_doppelganger('LabelSplits()-names', function() {
     tree <- BalancedTree(9)
     plot(tree)
     labs <- letters[1:6]
     LabelSplits(tree, labs, bg = 'orange')
-    expect_warning(LabelSplits(BalancedTree(9), setNames(letters[11:16], 1:6)))
   })
 })
